
# Type: sparqlpath

A string encoding a SPARQL Property Path. The value of the string MUST conform to SPARQL syntax and SHOULD dereference to zero or more valid objects within the current instance document when encoded as RDF.

URI: [linkml:Sparqlpath](https://w3id.org/linkml/Sparqlpath)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **str** |
| Representation | | str |
